@@ -374,13 +374,13 @@ class LocalWorkflow(object):
                         self.active_tag = str(tag)
 
             # I'm not sure that we need this any more, it predated the self.branch catch above for detacted HEAD
-            except TypeError as e:
+            except (TypeError, git.InvalidGitRepositoryError) as e:
                 log.error(
-                    "Could not fetch status of local Nextflow copy of {}:".format(self.full_name)
-                    + "\n   {}".format(str(e))
-                    + "\n\nIt's probably a good idea to delete this local copy and pull again:".format(self.local_path)
-                    + "\n   rm -rf {}".format(self.local_path)
-                    + "\n   nextflow pull {}".format(self.full_name)
+                    f"Could not fetch status of local Nextflow copy of '{self.full_name}':"
+                    f"\n   [red]{type(e).__name__}:[/] {str(e)}"
+                    "\n\nThis git repository looks broken. It's probably a good idea to delete this local copy and pull again:"
+                    f"\n   [magenta]rm -rf {self.local_path}"
+                    f"\n   [magenta]nextflow pull {self.full_name}",
                 )
 
 
